@@ -270,52 +270,62 @@ def draw_bbox(
 
 def draw_keypoints_labels(
     img: np.ndarray, keypoints: list, keypoint_labels: list, color: list=[0, 0, 255], font_face: int=cv2.FONT_HERSHEY_COMPLEX, thickness: int=1,
-    ignore_kpt_idx: list=[]
+    ignore_kpt_idx: list=[], font_scale: float=None, rel_org: (int, int)=None
 ):
     result = img.copy()
 
     # Define BBox enclosing keypoints
     np_kpts = np.array(keypoints)
     if len(np_kpts) > 0:
-        kpts_xmin, kpts_ymin = np.min(np_kpts, axis=0)
-        kpts_xmax, kpts_ymax = np.max(np_kpts, axis=0)
-        kpts_bbox = BBox(xmin=kpts_xmin, ymin=kpts_ymin, xmax=kpts_xmax, ymax=kpts_ymax)
-        bbox_h, bbox_w = kpts_bbox.shape()
-        
-        # Define target_textbox_w and initial font_scale guess.
-        target_textbox_w = 0.1 * bbox_w # Needs adjustment
-        font_scale = 1 * (target_textbox_w / 93)
+        if font_scale is None or rel_org is None:
+            kpts_xmin, kpts_ymin = np.min(np_kpts, axis=0)
+            kpts_xmax, kpts_ymax = np.max(np_kpts, axis=0)
+            kpts_bbox = BBox(xmin=kpts_xmin, ymin=kpts_ymin, xmax=kpts_xmax, ymax=kpts_ymax)
+            bbox_h, bbox_w = kpts_bbox.shape()
+            
+            # Define target_textbox_w and initial font_scale guess.
+            target_textbox_w = 0.1 * bbox_w # Needs adjustment
+            font_scale0 = 1 * (target_textbox_w / 93)
 
-        # Find max_size_label_idx
-        textbox_w, textbox_h = None, None
-        max_size_label_idx = None
-        for i, keypoint_label in enumerate(keypoint_labels):
-            [label_w, label_h], _ = cv2.getTextSize(text=keypoint_label, fontFace=font_face, fontScale=font_scale, thickness=thickness)
-            if textbox_w is None or label_w > textbox_w:
-                textbox_w, textbox_h = label_w, label_h
-                max_size_label_idx = i
+            # Find max_size_label_idx
+            textbox_w, textbox_h = None, None
+            max_size_label_idx = None
+            for i, keypoint_label in enumerate(keypoint_labels):
+                [label_w, label_h], _ = cv2.getTextSize(text=keypoint_label, fontFace=font_face, fontScale=font_scale0, thickness=thickness)
+                if textbox_w is None or label_w > textbox_w:
+                    textbox_w, textbox_h = label_w, label_h
+                    max_size_label_idx = i
 
-        # Prevent Divide By Zero Errors
-        target_textbox_w = target_textbox_w if target_textbox_w > 1 else 1
-        textbox_w = textbox_w if textbox_w > 1 else 1
-
-        # Adjust to target_textbox_w
-        retry_count = 0
-        while abs(textbox_w - target_textbox_w) / target_textbox_w > 0.1 and retry_count < 3:
-            retry_count += 1
-            font_scale = font_scale * (target_textbox_w / textbox_w)
-            [textbox_w, textbox_h], _ = cv2.getTextSize(text=keypoint_labels[max_size_label_idx], fontFace=font_face, fontScale=font_scale, thickness=thickness)
+            # Prevent Divide By Zero Errors
+            target_textbox_w = target_textbox_w if target_textbox_w > 1 else 1
             textbox_w = textbox_w if textbox_w > 1 else 1
-            textbox_h = textbox_h if textbox_h > 1 else 1
+
+            # Adjust to target_textbox_w
+            retry_count = 0
+            while abs(textbox_w - target_textbox_w) / target_textbox_w > 0.1 and retry_count < 3:
+                retry_count += 1
+                font_scale0 = font_scale0 * (target_textbox_w / textbox_w)
+                [textbox_w, textbox_h], _ = cv2.getTextSize(text=keypoint_labels[max_size_label_idx], fontFace=font_face, fontScale=font_scale0, thickness=thickness)
+                textbox_w = textbox_w if textbox_w > 1 else 1
+                textbox_h = textbox_h if textbox_h > 1 else 1
 
         # Draw Label
         for i, [[x, y], keypoint_label] in enumerate(zip(keypoints, keypoint_labels)):
             if i not in ignore_kpt_idx:
-                textbox_org_x = int(x - 0.5 * textbox_w)
-                textbox_org_y = int(y - 0.5 * textbox_h)
-                textbox_org = (textbox_org_x, textbox_org_y)
+                if rel_org is None:
+                    textbox_org_x = int(x - 0.5 * textbox_w)
+                    textbox_org_y = int(y - 0.5 * textbox_h)
+                    textbox_org = (textbox_org_x, textbox_org_y)
+                else:
+                    assert len(rel_org) == 2
+                    textbox_org_x = int(x + rel_org[0])
+                    textbox_org_y = int(y + rel_org[1])
+                    textbox_org = (textbox_org_x, textbox_org_y)
+                
                 cv2.putText(
-                    img=result, text=keypoint_label, org=textbox_org, fontFace=font_face, fontScale=font_scale, color=color,
+                    img=result, text=keypoint_label, org=textbox_org, fontFace=font_face,
+                    fontScale=font_scale0 if font_scale is None else font_scale,
+                    color=color,
                     thickness=thickness, bottomLeftOrigin=False
                 )
     return result
@@ -324,7 +334,7 @@ def draw_keypoints(
     img: np.ndarray, keypoints: list,
     radius: int=4, color: list=[0, 0, 255],
     keypoint_labels: list=None, show_keypoints_labels: bool=False, label_thickness: int=1, label_color: list=None, label_only: bool=False,
-    ignore_kpt_idx: list=[]
+    ignore_kpt_idx: list=[], font_scale: float=None
 ) -> np.ndarray:
     result = img.copy()
     if not (keypoint_labels is not None and label_only):
@@ -342,7 +352,7 @@ def draw_keypoints(
             text_color = label_color if label_color is not None else color
             result = draw_keypoints_labels(
                 img=result, keypoints=keypoints, keypoint_labels=keypoint_labels, color=text_color, thickness=label_thickness,
-                ignore_kpt_idx=ignore_kpt_idx
+                ignore_kpt_idx=ignore_kpt_idx, font_scale=font_scale
             )
         else:
             logger.error(f"Need to provide keypoint_labels in order to show labels.")
@@ -353,14 +363,14 @@ def draw_kpts2d(
     img: np.ndarray, keypoints: Keypoint2D_List,
     radius: int=4, color: list=[0, 0, 255],
     keypoint_labels: list=None, show_keypoints_labels: bool=False, label_thickness: int=1, label_color: list=None, label_only: bool=False,
-    ignore_kpt_idx: list=[]
+    ignore_kpt_idx: list=[], font_scale: float=None
 ):
     kpts = keypoints.to_numpy(demarcation=True)[:, :2].tolist()
     return draw_keypoints(
         img=img, keypoints=kpts, radius=radius, color=color,
         keypoint_labels=keypoint_labels, show_keypoints_labels=show_keypoints_labels,
         label_thickness=label_thickness, label_color=label_color, label_only=label_only,
-        ignore_kpt_idx=ignore_kpt_idx
+        ignore_kpt_idx=ignore_kpt_idx, font_scale=font_scale
     )
 
 def draw_skeleton(
